@@ -195,7 +195,7 @@ class MonsterGroup(Monster):
             self.individual_dam = f"{self.damage_dice}"
         self.at_will_dam = f"{smart_clamp(self.cr_val // 4, 1, 5)}d6 + {self.prof_bonus} {self.dam_type}"
 
-    def __str__(self):
+    def __repr__(self):
         self.output = (
             f"Monster Group: {self.name}, CR {cr_str(self.cr_val)}",
             f"Number Appearing: {self.num_appearing}",
@@ -251,7 +251,7 @@ class MinionGroup(Monster):
             self.individual_dam = f"{self.damage_dice}"
         self.at_will_dam = f"{smart_clamp(self.cr_val // 5, 1, 5)}d4 + {self.prof_bonus} {self.dam_type}"
 
-    def __str__(self):
+    def __repr__(self):
         self.output = (
             f"Minion Group: {self.name}, CR {cr_str(self.cr_val)}",
             f"Number Appearing: {self.num_appearing}",
@@ -286,7 +286,7 @@ class ItemEncounter(Monster):
 
     def __repr__(self):
         self.output = (
-            f"Animated Item: {self.item_name}, CR {cr_str(self.cr)}",
+            f"Animated Item: {self.item_name}, CR {cr_str(self.cr_val)}",
             # f"{self.ability_scores}",
             f"Hit Points: {self.total_hp}",
             f"Armor Class: {self.ac}",
@@ -467,4 +467,5 @@ class CampaignBoss(Boss):
 
 if __name__ == "__main__":
     print()
-    print(CampaignBoss(9, name="Black Blade Baron"))
+    # print(CampaignBoss(9, name="Black Blade Baron"))
+    print(ItemEncounter(10))
