@@ -1,8 +1,8 @@
 from Fortuna import *
-from DungeonLib.gear_lib import *
-from DungeonLib.monsters_lib import damage_type_cat
-from DungeonLib.treasure import Loot, get_loot, magic_table_by_cr
-from DungeonLib.utilities import damage_types
+from DungeonGenerator.gear_lib import *
+from DungeonGenerator.monsters_lib import damage_type_cat
+from DungeonGenerator.treasure import Loot, get_loot, magic_table_by_cr
+from DungeonGenerator.utilities import damage_types
 
 
 class Base:
