@@ -1,4 +1,4 @@
-from DungeonLib.npc_lib import npc_dict
+from DungeonGenerator.npc_lib import npc_dict
 
 
 things_dict = {
