@@ -1,5 +1,5 @@
 from Fortuna import *
-from DungeonLib.npc_lib import npc_dict
+from DungeonGenerator.npc_lib import npc_dict
 
 
 class SkillSet:
