@@ -92,7 +92,7 @@ class Loot:
             output = output[1:2]
         elif len(output) == 1:
             output = ['Empty']
-        return "\n  ".join(output) if len(output) > 1 else output[0]
+        return ", ".join(output) if len(output) > 1 else output[0]
 
     def set_loot(self, loot_data):
         loot = cumulative_weighted_choice(loot_data)
